@@ -34,4 +34,16 @@ def _default_docx_path():
     Return the path to the built-in default .docx package.
     """
     _thisdir = os.path.split(__file__)[0]
-    return os.path.join(_thisdir, 'templates', 'default-docx-template')
+    return os.path.join(_thisdir, 'templates', 'default.docx')
+
+
+def element(element, part):
+    if str(type(element)) == "<class 'docx.oxml.text.paragraph.CT_P'>":
+        from  .text.paragraph import  Paragraph
+        return Paragraph(element, part)
+    elif str(type(element)) == "<class 'docx.oxml.table.CT_Tbl'>":
+        from .table import Table
+        return Table(element, part)
+    elif str(type(element)) == "<class 'docx.oxml.section.CT_SectPr'>":
+        from .section import Section
+        return Section(element, part)
\ No newline at end of file
