@@ -1,24 +1,27 @@
 # encoding: utf-8
 
-"""
-Block item container, used by body, cell, header, etc. Block level items are
-things like paragraph and table, although there are a few other specialized
-ones like structured document tags.
+"""Block item container, used by body, cell, header, etc.
+
+Block level items are things like paragraph and table, although there are a few other
+specialized ones like structured document tags.
 """
 
-from __future__ import absolute_import, print_function
-
-from .shared import Parented
-from .text.paragraph import Paragraph
+from __future__ import absolute_import, division, print_function, unicode_literals
 
+from docx.oxml.table import CT_Tbl
+from docx.oxml.ns import  qn
+from docx.shared import Parented
+from docx.text.paragraph import Paragraph
+from docx.api import element
 
 class BlockItemContainer(Parented):
+    """Base class for proxy objects that can contain block items.
+
+    These containers include _Body, _Cell, header, footer, footnote, endnote, comment,
+    and text box objects. Provides the shared functionality to add a block item like
+    a paragraph or table.
     """
-    Base class for proxy objects that can contain block items, such as _Body,
-    _Cell, header, footer, footnote, endnote, comment, and text box objects.
-    Provides the shared functionality to add a block item like a paragraph or
-    table.
-    """
+
     def __init__(self, element, parent):
         super(BlockItemContainer, self).__init__(parent)
         self._element = element
@@ -37,19 +40,16 @@ class BlockItemContainer(Parented):
             paragraph.style = style
         return paragraph
 
-    def add_table(self, rows, cols):
+    def add_table(self, rows, cols, width):
         """
-        Return a newly added table having *rows* rows and *cols* cols,
-        appended to the content in this container.
+        Return a table of *width* having *rows* rows and *cols* columns,
+        newly appended to the content in this container. *width* is evenly
+        distributed between the table columns.
         """
         from .table import Table
-        tbl = self._element.add_tbl()
-        table = Table(tbl, self)
-        for i in range(cols):
-            table.add_column()
-        for i in range(rows):
-            table.add_row()
-        return table
+        tbl = CT_Tbl.new_tbl(rows, cols, width)
+        self._element._insert_tbl(tbl)
+        return Table(tbl, self)
 
     @property
     def paragraphs(self):
@@ -67,10 +67,23 @@ class BlockItemContainer(Parented):
         """
         from .table import Table
         return [Table(tbl, self) for tbl in self._element.tbl_lst]
+    @property
+    def elements(self):
+        """
+        A list containing the elements in this container (paragraph and tables), in document order.
+        """
+        return [element(item,self.part) for item in self._element.getchildren()]
+    
+    
+    @property
+    def abstractNumIds(self):
+        return [numId for numId in self.part.numbering_part.element.iterchildren(qn('w:abstractNum'))]
 
+    
     def _add_paragraph(self):
         """
         Return a paragraph newly added to the end of the content in this
         container.
         """
         return Paragraph(self._element.add_p(), self)
+
