@@ -1,33 +1,43 @@
 # encoding: utf-8
 
-"""
-|DocumentPart| and closely related objects
-"""
+"""|DocumentPart| and closely related objects"""
 
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from ..document import Document
-from .numbering import NumberingPart
-from ..opc.constants import RELATIONSHIP_TYPE as RT
-from ..opc.part import XmlPart
-from ..oxml.shape import CT_Inline
-from ..shape import InlineShapes
-from ..shared import lazyproperty
-from .settings import SettingsPart
-from .styles import StylesPart
+from docx.document import Document
+from docx.opc.constants import RELATIONSHIP_TYPE as RT
+from docx.parts.hdrftr import FooterPart, HeaderPart
+from docx.parts.numbering import NumberingPart
+from docx.parts.settings import SettingsPart
+from docx.parts.story import BaseStoryPart
+from docx.parts.styles import StylesPart
+from docx.parts.comments import CommentsPart
+from docx.parts.footnotes import FootnotesPart
+from docx.shape import InlineShapes
+from docx.shared import lazyproperty
 
 
-class DocumentPart(XmlPart):
-    """
-    Main document part of a WordprocessingML (WML) package, aka a .docx file.
-    Acts as broker to other parts such as image, core properties, and style
-    parts. It also acts as a convenient delegate when a mid-document object
-    needs a service involving a remote ancestor. The `Parented.part` property
-    inherited by many content objects provides access to this part object for
-    that purpose.
+class DocumentPart(BaseStoryPart):
+    """Main document part of a WordprocessingML (WML) package, aka a .docx file.
+
+    Acts as broker to other parts such as image, core properties, and style parts. It
+    also acts as a convenient delegate when a mid-document object needs a service
+    involving a remote ancestor. The `Parented.part` property inherited by many content
+    objects provides access to this part object for that purpose.
     """
+
+    def add_footer_part(self):
+        """Return (footer_part, rId) pair for newly-created footer part."""
+        footer_part = FooterPart.new(self.package)
+        rId = self.relate_to(footer_part, RT.FOOTER)
+        return footer_part, rId
+
+    def add_header_part(self):
+        """Return (header_part, rId) pair for newly-created header part."""
+        header_part = HeaderPart.new(self.package)
+        rId = self.relate_to(header_part, RT.HEADER)
+        return header_part, rId
+
     @property
     def core_properties(self):
         """
@@ -43,19 +53,13 @@ class DocumentPart(XmlPart):
         """
         return Document(self._element, self)
 
-    def get_or_add_image(self, image_descriptor):
-        """
-        Return an (rId, image) 2-tuple for the image identified by
-        *image_descriptor*. *image* is an |Image| instance providing access
-        to the properties of the image, such as dimensions and image type.
-        *rId* is the key for the relationship between this document part and
-        the image part, reused if already present, newly created if not.
-        """
-        image_part = self._package.image_parts.get_or_add_image_part(
-            image_descriptor
-        )
-        rId = self.relate_to(image_part, RT.IMAGE)
-        return rId, image_part.image
+    def drop_header_part(self, rId):
+        """Remove related header part identified by *rId*."""
+        self.drop_rel(rId)
+
+    def footer_part(self, rId):
+        """Return |FooterPart| related by *rId*."""
+        return self.related_parts[rId]
 
     def get_style(self, style_id, style_type):
         """
@@ -75,6 +79,10 @@ class DocumentPart(XmlPart):
         """
         return self.styles.get_style_id(style_or_name, style_type)
 
+    def header_part(self, rId):
+        """Return |HeaderPart| related by *rId*."""
+        return self.related_parts[rId]
+
     @lazyproperty
     def inline_shapes(self):
         """
@@ -83,31 +91,6 @@ class DocumentPart(XmlPart):
         """
         return InlineShapes(self._element.body, self)
 
-    def new_pic_inline(self, image_descriptor, width, height):
-        """
-        Return a newly-created `w:inline` element containing the image
-        specified by *image_descriptor* and scaled based on the values of
-        *width* and *height*.
-        """
-        rId, image = self.get_or_add_image(image_descriptor)
-        cx, cy = image.scaled_dimensions(width, height)
-        shape_id, filename = self.next_id, image.filename
-        return CT_Inline.new_pic_inline(shape_id, rId, filename, cx, cy)
-
-    @property
-    def next_id(self):
-        """Next available positive integer id value in this document.
-
-        Calculated by incrementing maximum existing id value. Gaps in the
-        existing id sequence are not filled. The id attribute value is unique
-        in the document, without regard to the element type it appears on.
-        """
-        id_str_lst = self._element.xpath('//@id')
-        used_ids = [int(id_str) for id_str in id_str_lst if id_str.isdigit()]
-        if not used_ids:
-            return 1
-        return max(used_ids) + 1
-
     @lazyproperty
     def numbering_part(self):
         """
@@ -121,6 +104,8 @@ class DocumentPart(XmlPart):
             numbering_part = NumberingPart.new()
             self.relate_to(numbering_part, RT.NUMBERING)
             return numbering_part
+    
+    
 
     def save(self, path_or_stream):
         """
@@ -171,3 +156,33 @@ class DocumentPart(XmlPart):
             styles_part = StylesPart.default(self.package)
             self.relate_to(styles_part, RT.STYLES)
             return styles_part
+    
+    @lazyproperty
+    def comments_part(self):
+        """
+        A |Comments| object providing read/write access to the core
+        properties of this document.
+        """
+        # return self.package._comments_part
+
+    @property
+    def _comments_part(self):
+        try:
+            return self.part_related_by(RT.COMMENTS)
+        except KeyError:
+            comments_part = CommentsPart.default(self) 
+            self.relate_to(comments_part, RT.COMMENTS)
+            return comments_part
+    
+    @property
+    def _footnotes_part(self):
+        """
+        |FootnotesPart| object related to this package. Creates
+        a default Comments part if one is not present.
+        """
+        try:
+            return self.part_related_by(RT.FOOTNOTES)
+        except KeyError:
+            footnotes_part = FootnotesPart.default(self)
+            self.relate_to(footnotes_part, RT.FOOTNOTES)
+            return  footnotes_part
\ No newline at end of file
