@@ -10,12 +10,14 @@ from .blkcntnr import BlockItemContainer
 from .enum.style import WD_STYLE_TYPE
 from .oxml.simpletypes import ST_Merge
 from .shared import Inches, lazyproperty, Parented
+from .section import Section
 
 
 class Table(Parented):
     """
     Proxy class for a WordprocessingML ``<w:tbl>`` element.
     """
+
     def __init__(self, tbl, parent):
         super(Table, self).__init__(parent)
         self._element = self._tbl = tbl
@@ -44,6 +46,10 @@ class Table(Parented):
             tc.width = gridCol.w
         return _Row(tr, self)
 
+    @property
+    def section(self):
+        return Section(self._element._section, self.part)
+
     @property
     def alignment(self):
         """
@@ -190,12 +196,11 @@ class Table(Parented):
 
 
 class _Cell(BlockItemContainer):
-    """
-    Table cell
-    """
+    """Table cell"""
+
     def __init__(self, tc, parent):
         super(_Cell, self).__init__(tc, parent)
-        self._tc = tc
+        self._tc = self._element = tc
 
     def add_paragraph(self, text='', style=None):
         """
@@ -242,6 +247,14 @@ class _Cell(BlockItemContainer):
         """
         return super(_Cell, self).paragraphs
 
+    @property
+    def comments(self):
+        comments = []
+        for paragraph in self.paragraphs:
+            comments += paragraph.comments
+
+        return comments
+
     @property
     def tables(self):
         """
@@ -270,6 +283,24 @@ class _Cell(BlockItemContainer):
         r = p.add_r()
         r.text = text
 
+    @property
+    def vertical_alignment(self):
+        """Member of :ref:`WdCellVerticalAlignment` or None.
+
+        A value of |None| indicates vertical alignment for this cell is
+        inherited. Assigning |None| causes any explicitly defined vertical
+        alignment to be removed, restoring inheritance.
+        """
+        tcPr = self._element.tcPr
+        if tcPr is None:
+            return None
+        return tcPr.vAlign_val
+
+    @vertical_alignment.setter
+    def vertical_alignment(self, value):
+        tcPr = self._element.get_or_add_tcPr()
+        tcPr.vAlign_val = value
+
     @property
     def width(self):
         """
@@ -286,6 +317,7 @@ class _Column(Parented):
     """
     Table column
     """
+
     def __init__(self, gridCol, parent):
         super(_Column, self).__init__(parent)
         self._gridCol = gridCol
@@ -329,6 +361,7 @@ class _Columns(Parented):
     Sequence of |_Column| instances corresponding to the columns in a table.
     Supports ``len()``, iteration and indexed access.
     """
+
     def __init__(self, tbl, parent):
         super(_Columns, self).__init__(parent)
         self._tbl = tbl
@@ -372,9 +405,18 @@ class _Row(Parented):
     """
     Table row
     """
+
     def __init__(self, tr, parent):
         super(_Row, self).__init__(parent)
-        self._tr = tr
+        self._tr = self._element = tr
+
+    @property
+    def text_as_lst(self):
+        return [cell.text for cell in self.cells]
+
+    @property
+    def text(self):
+        return ' '.join(self.text_as_lst)
 
     @property
     def cells(self):
@@ -383,6 +425,31 @@ class _Row(Parented):
         """
         return tuple(self.table.row_cells(self._index))
 
+    @property
+    def height(self):
+        """
+        Return a |Length| object representing the height of this cell, or
+        |None| if no explicit height is set.
+        """
+        return self._tr.trHeight_val
+
+    @height.setter
+    def height(self, value):
+        self._tr.trHeight_val = value
+
+    @property
+    def height_rule(self):
+        """
+        Return the height rule of this cell as a member of the
+        :ref:`WdRowHeightRule` enumeration, or |None| if no explicit
+        height_rule is set.
+        """
+        return self._tr.trHeight_hRule
+
+    @height_rule.setter
+    def height_rule(self, value):
+        self._tr.trHeight_hRule = value
+
     @property
     def table(self):
         """
@@ -403,6 +470,7 @@ class _Rows(Parented):
     Sequence of |_Row| objects corresponding to the rows in a table.
     Supports ``len()``, iteration, indexed access, and slicing.
     """
+
     def __init__(self, tbl, parent):
         super(_Rows, self).__init__(parent)
         self._tbl = tbl
